A tool and Python library for issuing out and integrating security tokens.


.. image:: https://badges.gitter.im/TokenMarketNet/sto.svg
   :alt: Join the chat at https://gitter.im/security-token/Lobby
   :target: https://gitter.im/security-token/Lobby

.. image:: https://img.shields.io/travis/TokenMarketNet/sto.svg
        :target: https://travis-ci.org/TokenMarketNet/sto


Benefits
========

An open source tool ensures your company can manage its security tokens now and in the far future without vendor lock in. A good documentation ensures any capable technical advisory can pick up the work and assist you.

Features
========

This is a command line tool and Python library to manage and integrate security tokens:

* Issue out new stock series

* Printing out cap table

* Printing out my portfolio

* Managing bad transactions and lost privat keys

* Paying dividends

* Delivering voting ballots

The command line tool is locally installed via Docker and available for Windows, OSX and Linux.

Get started
===========

* `Read an introduction for security tokens <https://tokenmarket.net/news/security-tokens/what-are-security-tokens/>`_

* `Read the documentation <https://docs.tokenmarket.net/>`_

Links
=====

`TokenMarket website <https://tokenmarket.net>`_

`Documentation <https://docs.tokenmarket.net/>`_

`Github Source code and issue tracker <https://github.com/tokenmarketnet/sto>`_

`Support and chat <https://gitter.im/security-token/Lobby>`_

`Docker releases <https://hub.docker.com/r/miohtama/sto/>`_

`Python releases <https://pypi.org/project/sto/>`_

`Smart contracts repository <http://github.com/tokenmarketnet/ico>`_








